@@ -62,6 +62,7 @@ our @EXPORT_OK = qw(
     needrestart_ui_init
     needrestart_interp_register
     needrestart_cont_register
+    needrestart_cont_register_fallback
 );
 
 our %EXPORT_TAGS = (
@@ -78,10 +79,11 @@ our %EXPORT_TAGS = (
     )],
     cont => [qw(
 	needrestart_cont_register
+	needrestart_cont_register_fallback
     )],
 );
 
-our $VERSION = '3.7';
+our $VERSION = '3.9';
 my $LOGPREF = '[Core]';
 
 my %UIs;
@@ -224,6 +226,7 @@ sub needrestart_interp_source($$$) {
 
 
 my %CONT;
+my %FALLBACK;
 my $ndebug;
 
 sub needrestart_cont_register($) {
@@ -232,6 +235,12 @@ sub needrestart_cont_register($) {
     $CONT{$pkg} = new $pkg($ndebug);
 }
 
+sub needrestart_cont_register_fallback($) {
+    my $pkg = shift;
+
+    $FALLBACK{$pkg} = new $pkg($ndebug);
+}
+
 sub needrestart_cont_init($) {
     $ndebug = shift;
 
@@ -254,6 +263,9 @@ sub needrestart_cont_check($$$;$) {
     foreach my $cont (values %CONT) {
 	return 1 if($cont->check($pid, $bin, $norestart));
     }
+    foreach my $cont (values %FALLBACK) {
+	return 1 if($cont->check($pid, $bin, $norestart));
+    }
 
     return 0;
 }
