@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2020 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -40,7 +40,6 @@ sub new {
     my $class = shift;
 
     my $self = $class->SUPER::new(@_);
-    die "Could not get NS PID of #1!\n" unless(defined($self->{nspid}));
 
     $self->{machined} = {};
     return bless $self, $class;
@@ -51,33 +50,26 @@ sub check {
     my $pid = shift;
     my $bin = shift;
     my $norestart = shift;
-    my $ns = $self->get_nspid($pid);
 
     # stop here if no dedicated PID namespace is used
-    return 0 if(!$ns || $ns == $self->{nspid});
+    return 0 unless $self->in_pidns($pid);
 
-    unless(open(FCG, qq(/proc/$pid/cgroup))) {
-	print STDERR "$LOGPREF #$pid: unable to open cgroup ($!)\n" if($self->{debug});
-	return 0;
-    }
-    my $cg;
-    {
-	local $/;
-	$cg = <FCG>;
-	close(FCG);
-    }
+    my $cg = nr_get_cgroup($pid);
 
-    # look for machined cgroups
-    return 0 unless($cg =~ /^\d+:[^:]+:\/machine.slice\/machine-(.+)\.scope$/m);
+    # look for machined or systemd-nspawn cgroups
+    return 0 unless($cg =~ m@^/machine\.slice/(machine)-([^.]+)\.scope(/|$)@m ||
+                    $cg =~ m@^/machine\.slice/(systemd-nspawn)\@([^.]+)\.service(/|$)@);
+
+    my $name = $2;
+    my $mgr = ($1 eq "machine") ? "systemd-machined" : $1;
 
-    my $name = $1;
     unless($norestart) {
-	print STDERR "$LOGPREF #$pid is part of systemd-machined container '$name' and should be restarted\n" if($self->{debug});
+	print STDERR "$LOGPREF #$pid is part of $mgr container '$name' and should be restarted\n" if($self->{debug});
 
 	$self->{machined}->{$name}++;
     }
     else {
-	print STDERR "$LOGPREF #$pid is part of systemd-machined container '$name'\n" if($self->{debug});
+	print STDERR "$LOGPREF #$pid is part of $mgr container '$name'\n" if($self->{debug});
     }
 
     return 1;
